import "./sso.config";
import {SsoModel} from "./sso.model";

const { shortcut, store } = BI.Decorators;

@shortcut()
@store(SsoModel)
export class List extends BI.Widget {
    static xtype = "dec.plugin.system.sso";

    props = {
        baseCls: "dec-plugin-system-sso bi-card",
    };

    watch = {
        "config.publicKey": (val) => {
            this.publicKey.setValue(val);
        },

        emptyPublicKey: (b) => {
            this.publicKeyContainer.setVisible(!b);
        },

        showIndex: (v) => {
            this.tab.setSelect(v);
        }
    };

    publicKey = null;

    tab = null;

    beforeInit(render) {
        this.store.getSsoConfig(render);
    }

    render() {

        return {
            type: "bi.absolute",
            items: [
                {
                    el: {
                        type: "bi.vertical",
                        vgap: 15,
                        hgap: 10,
                        items: [
                            {
                                el: {
                                    type: "bi.vertical_adapt",
                                    columnSize: [116, ""],
                                    items: [
                                        {
                                            el: {
                                                type: "bi.label",
                                                textAlign: "left",
                                                text: BI.i18nText("Dec-System_Background_SSO"),
                                                cls: "dec-font-weight-bold",
                                                height: 24,
                                            }
                                        }, {
                                            el: {
                                                type: "bi.button_group",
                                                layouts: [
                                                    {
                                                        type: "bi.vertical_adapt",
                                                        rgap: 15
                                                    }
                                                ],
                                                value: this.model.showIndex,
                                                items: [
                                                    {
                                                        type: "bi.single_select_radio_item",
                                                        logic: {
                                                            dynamic: true
                                                        },
                                                        text: BI.i18nText("Dec-Plugin_System_Sso_Username_Encrypt"),
                                                        value: "main"
                                                    }, {
                                                        text: BI.i18nText("Dec-Plugin_System_Sso_Demo"),
                                                        value: "demo",
                                                        type: "bi.single_select_radio_item",
                                                        logic: {
                                                            dynamic: true
                                                        },
                                                    }
                                                ],
                                                listeners: [
                                                    {
                                                        eventName: "EVENT_CHANGE",
                                                        action: (v) => {
                                                            this.store.changeMode(v);
                                                        }
                                                    }
                                                ]
                                            }
                                        }
                                    ]
                                }
                            }, {
                                type: "bi.tab",
                                ref: (ref) => {
                                    this.tab = ref;
                                },
                                single: false,
                                logic: {
                                    dynamic: true
                                },
                                showIndex: this.model.showIndex,
                                cardCreator: (v) => {
                                    if (v === "demo") {
                                        return this.createDemo();
                                    }
                                    return this.createMain();
                                }
                            },
                        ],
                    },
                    top: 0, left: 0, right: 0, bottom: 0
                }, {
                    el: {
                        type: "bi.button",
                        text: BI.i18nText("Dec-Basic_Save"),
                        handler: () => {
                            this.store.saveSsoConfig();
                        }
                    },
                    top: -40,
                    right: 0
                }
            ]
        };
    }

    createDemo() {
        return {
            type: "bi.vertical",
            items: [
                {
                    el: {
                        type: "bi.label",
                        cls: "bi-tips",
                        textAlign: "left",
                        text: BI.i18nText("Dec-Plugin_System_Sso_Demo_Tip"),
                        lgap: 116
                    }
                }
            ]
        };
    }

    createMain() {

        let switchButton;

        return {
            type: "bi.vertical",
            bgap: 15,
            items: [
                {
                    el: this.createPublicKey()
                }, {
                    el: {
                        type: "bi.vertical_adapt",
                        columnSize: [116, "", ""],
                        items: [
                            {
                                el: {
                                    type: "bi.label",
                                    textAlign: "left",
                                    text: BI.i18nText("Dec-Plugin_System_Sso_Username_Encrypt"),
                                    cls: "dec-font-weight-bold",
                                    height: 24,
                                }
                            }, {
                                el: {
                                    type: "bi.label",
                                    textAlign: "left",
                                    text: BI.i18nText("Dec-Plugin_System_Sso_Encrypt_Public_Key_Tip"),
                                    cls: "",
                                    height: 24,
                                }
                            }, {
                                el: {
                                    type: "bi.link",
                                    textAlign: "left",
                                    text: BI.i18nText("Dec-Basic_Help_Document"),
                                    href: Dec.system[DecCst.Hyperlink.DECISION_HYPERLINK_CONFIG]["backgroundSso"],
                                    cls: "bi-high-light-border-bottom bi-high-light",
                                    height: 24,
                                },
                            }
                        ]
                    }
                }, {
                    el: {
                        type: "bi.vertical_adapt",
                        columnSize: [116, 200, ""],
                        items: [
                            {
                                el: {
                                    type: "bi.label",
                                    textAlign: "left",
                                    text: BI.i18nText("Dec-Plugin_System_Sso_Decrypt_Test"),
                                    cls: "dec-font-weight-bold",
                                    height: 24,
                                }
                            }, {
                                el: {
                                    type: "bi.text_editor",
                                    ref: (_ref) => {
                                        this.ciphertextEditor = _ref;
                                    },
                                    textAlign: "left",
                                    text: BI.i18nText("Dec-Plugin_System_Sso_Decrypt_Test_Watermark"),
                                    allowBlank: false,
                                    errorText: BI.i18nText("Dec-Error_Null"),
                                    height: 24,
                                }
                            }, {
                                el: {
                                    type: "bi.button",
                                    text: BI.i18nText("Dec-Plugin_System_Sso_Decrypt"),
                                    height: 24,
                                    handler: () => {
                                        const ciphertext = this.ciphertextEditor.getValue();
                                        if (BI.isKey(ciphertext)) {
                                            this.store.decryptTest(ciphertext);
                                            return;
                                        }
                                        this.ciphertextEditor.focus();
                                    }
                                },
                                hgap: 10,
                            }
                        ]
                    }
                }, {
                    el: {
                        type: "bi.vertical_adapt",
                        columnSize: [116, "", ""],
                        items: [
                            {
                                el: {
                                    type: "bi.label",
                                    textAlign: "left",
                                    text: BI.i18nText("Dec-Plugin_System_Sso_Time_Out_Config"),
                                    cls: "dec-font-weight-bold",
                                    height: 24,
                                }
                            }, {
                                el: {
                                    type: "bi.switch",
                                    ref: (ref) => {
                                        switchButton = ref;
                                    },
                                    selected: this.model.config.openTimeout,
                                    handler: () => {
                                        this.store.changeSsoTokenTimeOut(switchButton.isSelected());
                                    }
                                }
                            }, {
                                el: {
                                    type: "bi.label",
                                    textAlign: "left",
                                    text: BI.i18nText("Dec-Plugin_System_Sso_Time_Out_Config_Tip"),
                                    cls: "bi-tips",
                                    height: 24,
                                },
                                hgap: 10
                            }
                        ]
                    }
                }
            ]
        };
    }

    createPublicKey() {
        return {
            type: "bi.horizontal",
            verticalAlign: "top",
            horizontalAlign: "left",
            columnSize: [116, "fill"],
            items: [
                {
                    el: {
                        type: "bi.label",
                        textAlign: "left",
                        text: "RSA Key",
                        cls: "dec-font-weight-bold",
                        height: 24,
                    }
                }, {
                    el: {
                        type: "bi.vertical",
                        items: [
                            {
                                el: {
                                    type: "bi.vertical_adapt",
                                    columnSize: [106, ""],
                                    items: [
                                        {
                                            el: {
                                                type: "bi.bubble_combo",
                                                ref: (_ref) => {
                                                    this.bubbleCombo = _ref;
                                                },
                                                trigger: "",
                                                direction: "bottom,right",
                                                el: {
                                                    type: "bi.button",
                                                    text: BI.i18nText("Dec-Plugin_System_Sso_Generate_Rsa_Key"),
                                                    handler: () => {
                                                        if (this.model.emptyPublicKey) {
                                                            this.store.generateRsaKey();
                                                        } else {
                                                            this.bubbleCombo.showView();
                                                        }
                                                    }
                                                },
                                                popup: {
                                                    type: "bi.text_bubble_bar_popup_view",
                                                    text: BI.i18nText("Dec-Plugin_System_Sso_Generate_Rsa_Key_Confirm"),
                                                    listeners: [
                                                        {
                                                            eventName: BI.TextBubblePopupBarView.EVENT_CHANGE,
                                                            action: (b) => {
                                                                console.log(b);
                                                                b && this.store.generateRsaKey();
                                                                this.bubbleCombo.hideView();
                                                            }
                                                        }
                                                    ]
                                                }
                                            }
                                        }, {
                                            el: {
                                                type: "bi.label",
                                                text: BI.i18nText("Dec-Plugin_System_Sso_Rsa_Key_Usage_Tip"),
                                                cls: "bi-tips",
                                                hgap: 10,
                                            }
                                        }
                                    ]
                                }
                            }, {
                                el: {
                                    type: "bi.horizontal",
                                    ref: (_ref) => {
                                        this.publicKeyContainer = _ref;
                                    },
                                    invisible: this.model.emptyPublicKey,
                                    verticalAlign: "top",
                                    horizontalAlign: "left",
                                    columnSize: [106, "", ""],
                                    items: [
                                        {
                                            el: {
                                                type: "bi.label",
                                                textAlign: "left",
                                                text: "Public Key",
                                                height: 24,
                                            }
                                        }, {
                                            el: {
                                                type: "bi.textarea_editor",
                                                ref: (_ref) => {
                                                    this.publicKey = _ref;
                                                },
                                                cls: "bi-border",
                                                disabled: true,
                                                value: this.model.config.publicKey,
                                                height: 80,
                                                width: 460
                                            },
                                            lgap: 10
                                        }, {
                                            el: {
                                                type: "bi.clipboard",
                                                el: {
                                                    type: "bi.text_button",
                                                    cls: "bi-high-light",
                                                    text: BI.i18nText("Dec-Basic_Copy"),
                                                    hgap: 10,
                                                },
                                                height: 24,
                                                copy: () => {
                                                    return this.model.config.publicKey;
                                                },
                                                afterCopy: () => {
                                                    BI.Msg.toast(BI.i18nText("Dec-Basic_Copy_Success"), { level: "success" });
                                                }
                                            },
                                            tgap: 56
                                        }
                                    ]
                                },
                                tgap: 10,
                            },
                        ]
                    }
                },
            ]
        };
    }
}
