import * as api from "./sso.request";
import {getSsoConfig} from "./sso.request";

const { shortcut, model, store } = BI.Decorators;

@model()
export class SsoModel extends Fix.Model {
    static xtype = "dec.model.plugin.system.sso";

    state() {
        return {
            config: {
                publicKey: "",
                isDemo: true,
                openTimeout: true,
            }
        };
    }

    computed = {
        emptyPublicKey: () => !BI.isKey(this.model.config.publicKey),

        showIndex: () => this.model.config.isDemo ? "demo" : "main"
    };

    actions = {
        generateRsaKey() {
            api.generateKey().then(res => {
                BI.isKey(this.model.config.publicKey) && BI.Msg.toast(BI.i18nText("Dec-Plugin_System_Sso_Re_Generate_Rsa_Key_Success"), { level: "success" });
                this.model.config.publicKey = BI.aesDecrypt(res.data.publicKey, Dec.system.frontSeed);
            });
        },

        getSsoConfig(callback) {
            api.getSsoConfig().then(res => {
                this.model.config.publicKey = BI.aesDecrypt(res.data.publicKey, Dec.system.frontSeed);
                this.model.config.isDemo = res.data.isDemo;
                this.model.config.openTimeout = res.data.openTimeout;
                callback && callback();
            });
        },

        decryptTest(ciphertext) {
            api.decryptTest(ciphertext).then(res => {
                BI.Msg.alert(BI.i18nText("Dec-Basic_Tip"), BI.i18nText("Dec-Plugin_System_Sso_Decrypt_Test_Success", res.data.username));
            }).catch(err => {
                BI.Msg.alert(BI.i18nText("Dec-Basic_Tip"), BI.i18nText("Dec-Plugin_System_Sso_Decrypt_Test_Failed"));
            });
        },

        changeMode(v) {
            this.model.config.isDemo = v === "demo";
        },

        changeSsoTokenTimeOut(b) {
            this.model.config.openTimeout = b;
        },

        saveSsoConfig() {
            api.saveSsoConfig(BI.pick(this.model.config, ["isDemo", "openTimeout"])).then(res => {
                BI.Msg.toast(BI.i18nText("Dec-Basic_Save_Success"), { level: "success" });
            });
        },
    };
}
